searchData={"items":[{"type":"module","title":"Fireside","doc":"This is the documentation for the Fireside project.","ref":"Fireside.html"},{"type":"function","title":"Fireside.component_installed?/1","doc":"Checks if the provided component is installed in the current project.","ref":"Fireside.html#component_installed?/1"},{"type":"function","title":"Examples - Fireside.component_installed?/1","doc":"iex> Fireside.component_installed?(:example_component)\n    false","ref":"Fireside.html#component_installed?/1-examples"},{"type":"function","title":"Fireside.install/3","doc":"Installs a Fireside component into the project.\n\nThis is done by importing files listed in `config/0` (in `fireside.exs`) of the target component.\nIf the component defines a `setup/1` method, it will also be called.","ref":"Fireside.html#install/3"},{"type":"function","title":"Parameters - Fireside.install/3","doc":"- `component_name`: The name of the component to install. It can be an atom or a string.\n  - `source`: The source from which to install the component. The supported formats are:\n    - `[path: component_path]`: Install from a local path.\n    - `[{:git, git_url} | git_opts]`: Install from a Git repository. `git_opts` can include `:ref`, `:branch`, or `:tag`.\n    - `[{:github, github_repo} | git_opts]`: Install from a GitHub repository. `git_opts` can include `:ref`, `:branch`, or `:tag`.\n  - `opts`: A keyword list of options. Supported options include:\n    - `:unlocked?` - When true, the component is installed without being tracked by Fireside.\n    - `:yes?` - When true, auto-accepts all prompts during installation.","ref":"Fireside.html#install/3-parameters"},{"type":"function","title":"Examples - Fireside.install/3","doc":"iex> Fireside.install(:my_component, [path: \"/path/to/component\"], unlocked?: true)\n    :ok\n\n    iex> Fireside.install(:my_component, [git: \"https://github.com/user/repo.git\"] ++ [tag: \"v1.0.0\"])\n    :ok\n\n    iex> Fireside.install(:my_component, [github: \"user/repo\"] ++ [branch: \"main\"])\n    :ok","ref":"Fireside.html#install/3-examples"},{"type":"function","title":"Fireside.uninstall/2","doc":"Uninstalls a Fireside component from the project.\n\nThis function will attempt to remove all files and configurations associated with the component that were\nmanaged by Fireside. However, there are certain manual steps you may need to perform after the\nuninstallation; read more in the \"Warning\" below.","ref":"Fireside.html#uninstall/2"},{"type":"function","title":"Parameters - Fireside.uninstall/2","doc":"- `component_name`: The name of the component to uninstall. It can be an atom or a string.\n  - `opts`: A keyword list of options. Supported options include:\n    - `:yes?` - When true, auto-accepts all prompts during the uninstallation.\n\n>","ref":"Fireside.html#uninstall/2-parameters"},{"type":"function","title":"Warning {: .warning} - Fireside.uninstall/2","doc":">\n> After uninstalling a component, you may need to manually:\n> \n> - **Remove Optional or Manually Added Files**: If the component installation added files that were not tracked by Fireside\n>   (e.g., files that were marked as `:optional` or added outside the standard component structure via Igniter),\n>   these will not be automatically deleted. You will need to identify and remove these files yourself, if needed.\n> - **Cleanup Configuration Changes**: If the component installation modified configuration files\n>   (e.g., `config/config.exs`, `config/dev.exs`), these changes will not be reverted automatically.\n>   Review these files and manually remove any settings or configurations related to the uninstalled component.\n> - **Remove Unused Dependencies**: Dependencies installed alongside the component will not be automatically\n>   removed, as Fireside cannot determine if they are used elsewhere in your project. You may need to manually\n>   remove these dependencies from your `mix.exs` file and run `mix deps.clean` to fully remove them from your project.","ref":"Fireside.html#uninstall/2-warning-warning"},{"type":"function","title":"Examples - Fireside.uninstall/2","doc":"iex> Fireside.uninstall(:my_component)\n    :ok","ref":"Fireside.html#uninstall/2-examples"},{"type":"function","title":"Fireside.unlock/2","doc":"Unlocks a Fireside component, removing it from Fireside's tracking without deleting it.\n\nThis is useful if you want to continue using the component but no longer want it to be managed\nby Fireside.","ref":"Fireside.html#unlock/2"},{"type":"function","title":"Parameters - Fireside.unlock/2","doc":"- `component_name`: The name of the component to unlock. It can be an atom or a string.\n  - `opts`: A keyword list of options. Supported options include:\n    - `:yes?` - When true, auto-accepts all prompts during the unlock process.","ref":"Fireside.html#unlock/2-parameters"},{"type":"function","title":"Examples - Fireside.unlock/2","doc":"iex> Fireside.unlock(:my_component)\n    :ok","ref":"Fireside.html#unlock/2-examples"},{"type":"function","title":"Fireside.update/3","doc":"Updates a previously installed Fireside component.\n\nThis is done by reimporting files listed in `config/0` (in `fireside.exs`) of the target component.\nIf the component's version is being changed and a corresponding `upgrade/3` migration is defined,\nit will also be executed. (Note: multiple `upgrade/3` migrations may be executed if the app's\nversion is changed by more than 1.)\n\nBefore updating, the integrity of the installed component will be checked by comparing the hash\nof the AST with the hash listed in `config/fireside.exs`. If the installed component has been\nmodified and has diverged from its original source, the operation will be aborted, as it might\nlead to a regression since any added/removed functionality may be overwritten by remote updates.\nIn this case, it is recommended to run `unlock/2` to instruct Fireside to stop tracking the\ncomponent's source.","ref":"Fireside.html#update/3"},{"type":"function","title":"Parameters - Fireside.update/3","doc":"- `component_name`: The name of the component to update. It can be an atom or a string.\n  - `source`: The source from which to update the component. If `nil` (default), the source from the\n    local component configuration is used. Otherwise, the supported formats are:\n    - `[path: component_path]`: Install from a local path.\n    - `[{:git, git_url} | git_opts]`: Install from a Git repository. `git_opts` can include `:ref`, `:branch`, or `:tag`.\n    - `[{:github, github_repo} | git_opts]`: Install from a GitHub repository. `git_opts` can include `:ref`, `:branch`, or `:tag`.\n  - `opts`: A keyword list of options. Supported options include:\n    - `:yes?` - When true, auto-accepts all prompts during the update.","ref":"Fireside.html#update/3-parameters"},{"type":"function","title":"Examples - Fireside.update/3","doc":"iex> Fireside.update(:my_component)\n    :ok\n\n    iex> Fireside.update(:my_component, [git: \"https://github.com/user/repo.git\"] ++ [branch: \"dev\"])\n    :ok","ref":"Fireside.html#update/3-examples"},{"type":"task","title":"mix fireside.install","doc":"Installs a Fireside component. This task runs `Fireside.install/3`.","ref":"Mix.Tasks.Fireside.Install.html"},{"type":"task","title":"Usage - mix fireside.install","doc":"`mix fireside.install component@...`","ref":"Mix.Tasks.Fireside.Install.html#module-usage"},{"type":"task","title":"Supported formats - mix fireside.install","doc":"* `component@path:/path/to/component`\n* `component@git:{git_uri}`\n* `component@git:{git_uri}@ref:{ref}`\n* `component@git:{git_uri}@branch:{ref}`\n* `component@git:{git_uri}@tag:{ref}`\n* `component@github:{org}/{repo_name}`\n* `component@github:{org}/{repo_name}@ref:{ref}`\n* `component@github:{org}/{repo_name}@branch:{branch}`\n* `component@github:{org}/{repo_name}@tag:{tag}`","ref":"Mix.Tasks.Fireside.Install.html#module-supported-formats"},{"type":"task","title":"Options - mix fireside.install","doc":"* `--unlocked` - the component will be installed without being tracked by Fireside.\n* `--yes` - auto-accept all prompts","ref":"Mix.Tasks.Fireside.Install.html#module-options"},{"type":"task","title":"mix fireside.uninstall","doc":"Uninstalls a Fireside component. This task runs `Fireside.uninstall/2`.","ref":"Mix.Tasks.Fireside.Uninstall.html"},{"type":"task","title":"Usage - mix fireside.uninstall","doc":"`mix fireside.uninstall component`","ref":"Mix.Tasks.Fireside.Uninstall.html#module-usage"},{"type":"task","title":"Supported formats - mix fireside.uninstall","doc":"* `component` - The installed component's name.","ref":"Mix.Tasks.Fireside.Uninstall.html#module-supported-formats"},{"type":"task","title":"Options - mix fireside.uninstall","doc":"* `--yes` - auto-accept all prompts","ref":"Mix.Tasks.Fireside.Uninstall.html#module-options"},{"type":"task","title":"mix fireside.unlock","doc":"Unlocks a Fireside component. This task runs `Fireside.unlock/2`.","ref":"Mix.Tasks.Fireside.Unlock.html"},{"type":"task","title":"Usage - mix fireside.unlock","doc":"`mix fireside.unlock component`","ref":"Mix.Tasks.Fireside.Unlock.html#module-usage"},{"type":"task","title":"Supported formats - mix fireside.unlock","doc":"* `component` - The installed component's name.","ref":"Mix.Tasks.Fireside.Unlock.html#module-supported-formats"},{"type":"task","title":"Options - mix fireside.unlock","doc":"* `--yes` - auto-accept all prompts","ref":"Mix.Tasks.Fireside.Unlock.html#module-options"},{"type":"task","title":"mix fireside.update","doc":"Updates a Fireside component. This task runs `Fireside.update/3`.","ref":"Mix.Tasks.Fireside.Update.html"},{"type":"task","title":"Usage - mix fireside.update","doc":"`mix fireside.update component@...`","ref":"Mix.Tasks.Fireside.Update.html#module-usage"},{"type":"task","title":"Supported formats - mix fireside.update","doc":"* `component` - The component's source will be fetched from the local component config (in `config/fireside.exs`).\n* `component@path:/path/to/component`\n* `component@git:{git_uri}`\n* `component@git:{git_uri}@ref:{ref}`\n* `component@git:{git_uri}@branch:{ref}`\n* `component@git:{git_uri}@tag:{ref}`\n* `component@github:{org}/{repo_name}`\n* `component@github:{org}/{repo_name}@ref:{ref}`\n* `component@github:{org}/{repo_name}@branch:{branch}`\n* `component@github:{org}/{repo_name}@tag:{tag}`","ref":"Mix.Tasks.Fireside.Update.html#module-supported-formats"},{"type":"task","title":"Options - mix fireside.update","doc":"* `--yes` - auto-accept all prompts","ref":"Mix.Tasks.Fireside.Update.html#module-options"},{"type":"extras","title":"Overview","doc":"[![Hex version badge](https://img.shields.io/hexpm/v/fireside.svg)](https://hex.pm/packages/fireside)\n[![Hexdocs badge](https://img.shields.io/badge/docs-hexdocs-purple)](https://hexdocs.pm/fireside)\n\n# Fireside\n\nFireside is a small Elixir library that allows importing code components\n(templates) into an existing Elixir project together with their dependencies.\nIt also allows _upgrading_ these components if they have a newer version\navailable.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"```elixir\ndef deps do\n  [\n    {:fireside, \"~> 0.1\", only: :dev, runtime: false}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Use cases - Overview","doc":"- **_Embedded_ microservices**: using Fireside allows to split up a monolith into\n  microservices while _still maintaining the monolith_. You get the benefits of\n  both worlds:\n  - Isolated, testable microservices and improved developer productivity in\n    larger teams.\n  - One distributed BEAM runtime.\n\n  Typically, a monolith approach comes with slower reviews (in larger teams) and\n  the microservices approach comes with additional complexity, the need for\n  communication protocols, queues, etc. With Fireside and Elixir, you can\n  develop individual microservices and embed them into your monolith\n  with one command. You can even embed them in multiple monoliths.\n- **Framework templates**: if you ever created a Phoenix project, you most\n  likely created it with `mix phx.new ...`, which creates a brand new\n  Elixir application. This comes with a major drawback: it requires, well, a\n  _new_ Elixir project. If Phoenix's template was a Fireside component, it\n  would've been possible to add it to an _existing_ Elixir app.\n- **Portable business logic**: if you are a development agency, you can extract\n  reusable code into individual Fireside components, reuse them in your\n  projects, and update all your projects with one command.\n- **Paid components**: if you run something like [Petal](https://petal.build/),\n  you can make your components installable in one CLI command using Fireside.\n  If you ever release a new version, they can be updated in one command as\n  well.\n- **Tutorials**: suppose you are writing a great coding tutorial such as\n  [Small Development Kits](https://dashbit.co/blog/sdks-with-req-stripe) or\n  [S3 with Tigris](https://fly.io/phoenix-files/what-if-s3-could-be-a-fast-globally-synced-key-value-database-that-s-tigris/).\n  You can make the code available as a Fireside component, which means your\n  readers can import it to an existing project with just one CLI command.","ref":"readme.html#use-cases"},{"type":"extras","title":"Usage - Overview","doc":"To see supported Fireside tasks, refer to\n[Mix Tasks](https://hexdocs.pm/fireside/api-reference.html#mix-tasks).","ref":"readme.html#usage"},{"type":"extras","title":"Upgrading code components with Fireside - Overview","doc":"Fireside supports two modes of installing a code component (template): locked\nand unlocked. If you are installing a code component in the \"unlocked\" mode,\nit will just install the code and forget about it. If you are installing it in\nthe \"locked\" mode (default), it will compute the hash of its AST, annotate each\ngenerated file as \"DO NOT EDIT\", and record the hash in `config/fireside.exs`.\nLater, when updating to a newer version, Fireside will know which files belong\nto which component and whether they have been mistakenly modified.","ref":"readme.html#upgrading-code-components-with-fireside"},{"type":"extras","title":"Example Fireside component - Overview","doc":"To see an example Fireside component, check out [Shopifex](https://github.com/ibarakaiev/shopifex),\na component that provides the backbone for an e-commerce online store.","ref":"readme.html#example-fireside-component"},{"type":"extras","title":"Creating a Fireside component","doc":"# Creating a Fireside component","ref":"creating-components.html"},{"type":"extras","title":"Fireside config - Creating a Fireside component","doc":"In order to turn an existing Elixir project into a Fireside component, you\nsimply need to add a `fireside.exs` file in the root of your project,\nwith contents similar to the following:\n\n```elixir\ndefmodule MyComponent.FiresideConfig do\n  def config do\n    [\n      name: :my_component,\n      version: 1,\n      files: [\n        required: [\n          \"lib/my_component/context.ex\",\n          \"lib/my_component/context/**/*.{ex,exs}\",\n          \"test/my_component/**/*_test.{ex,exs}\"\n        ],\n        optional: [\n          \"lib/shopifex_web/endpoint.ex\"\n        ]\n      ]\n    ]\n  end\nend\n```\n\nIgniter will then import all files at the provided globs and replace\n`MyComponent` with the name of your app (e.g. `MyApp`) and `:my_component`\nwith the Mix project name of your app (e.g. `:my_app`).\n\n>","ref":"creating-components.html#fireside-config"},{"type":"extras","title":"Note {: .info} - Creating a Fireside component","doc":"> Replacing is done by comparing prefixes; that is, `MyComponentWeb` will\n> become `MyAppWeb`. Similarly, `:my_component_web` will become \n> `my_app_web`.","ref":"creating-components.html#note-info"},{"type":"extras","title":"Required files - Creating a Fireside component","doc":"Files marked as `required` will be installed if there are no existing\nconflicting files with the same name. Fireside will track these files in\n`config/fireside.exs` and they will be updated each time they are updated\nin the remote.","ref":"creating-components.html#required-files"},{"type":"extras","title":"Optional files - Creating a Fireside component","doc":"Files marked as `optional` will be installed only if they don't already exist.\n(This also means that they will only ever be installed once, even if their\nremote implementation changes.)\n\nFor example, if you're working on a component that emits messages to PubSub\n(but doesn't require receiving messages from it), you may add a simple\nplaceholder implementation like:\n\n```elixir\ndefmodule MyComponentWeb.Endpoint do\n  def broadcast(_, _, _), do: :ok\nend\n```\n\nThen, if the component is being imported into a Phoenix project, the default\nPhoenix `endpoint.ex` will remain used; otherwise, the optional placeholder\nimplementation will be used.\n\nFireside _does not_ track optional files in `config/fireside.exs`.","ref":"creating-components.html#optional-files"},{"type":"extras","title":"Additional setup (optional) - Creating a Fireside component","doc":"Sometimes, simply importing files is not sufficient to fully install a\ncomponent. For instance, if the configuration in `config/config.exs` needs\nto change for the component to work, you may define a `setup/1` method and\nuse [Igniter](https://hexdocs.pm/igniter) to add manual code generation\nlogic.\n\nFor example, if you are adding [Ash](https://hexdocs.pm/ash) resources, you may\nneed to add domains to `config :my_app, ash_domains: []` and generate\nmigrations. You can achieve this with the following `setup/1` function:\n\n```elixir\ndef setup(igniter) do\n  app_name = Igniter.Project.Application.app_name()\n\n  igniter\n  |> Igniter.Project.Config.configure(\n    \"config.exs\",\n    app_name,\n    [:ash_domains],\n    [MyComponent.Products],\n    updater: fn zipper ->\n      Igniter.Code.List.append_new_to_list(zipper, MyComponent.Products)\n    end\n  )\n  |> Ash.Igniter.codegen(\"setup_products\")\n  |> Igniter.add_notice(\"Make sure to run `mix ash.migrate`.\")\nend\n```\n\nNote: `setup/1` needs to return an `%Igniter{}` as well.","ref":"creating-components.html#additional-setup-optional"},{"type":"extras","title":"Versioning - Creating a Fireside component","doc":"Fireside supports component versioning. Sometimes, these version changes\nrequire manual steps such as changing configuration, generating migrations, or\nsimply adding plain notices. In that case, optional `upgrade/3` hooks can be\ndefined. They look as follows:\n\n```elixir\ndef upgrade(igniter, 1, 2) do\n  # add component migration logic here\n  igniter\n  |> ...\nend\n```","ref":"creating-components.html#versioning"},{"type":"extras","title":"Changelog","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n## [v0.1.3](https://github.com/ibarakaiev/fireside/compare/v0.1.2...v0.1.3) (2024-08-16)","ref":"changelog.html"},{"type":"extras","title":"Fixes - Changelog","doc":"- remove `append?: true` when installing components (will be reverted)\n- minor wording changes across documentation\n\n## [v0.1.2](https://github.com/ibarakaiev/fireside/compare/v0.1.1...v0.1.2) (2024-08-14)","ref":"changelog.html#fixes"},{"type":"extras","title":"Improvements - Changelog","doc":"- add small Fireside logo to docs\n\n## [v0.1.1](https://github.com/ibarakaiev/fireside/compare/v0.1.0...v0.1.1) (2024-08-14)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements - Changelog","doc":"- add Fireside logo and hex badges","ref":"changelog.html#improvements"},{"type":"extras","title":"Fixes - Changelog","doc":"- typos\n\n## [v0.1.0](https://github.com/ibarakaiev/fireside/compare/v0.0.3...v0.1.0) (2024-08-14)","ref":"changelog.html#fixes"},{"type":"extras","title":"Improvements - Changelog","doc":"- change the format of `fireside.exs` and `config/fireside.exs`\n- add `fireside.unlock` and `fireside.uninstall`\n- add versioning and component upgrades\n- add `--unlocked` option to `fireside.install` and `--yes` option to all tasks\n- add Git and Github support\n- documentation improvements\n\n## [v0.0.3](https://github.com/ibarakaiev/fireside/compare/v0.0.2...v0.0.3) (2024-08-01)","ref":"changelog.html#improvements"},{"type":"extras","title":"Improvements - Changelog","doc":"- Add Changelog to docs","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"- support no `overwritable` in `fireside.install`.\n\n## [v0.0.2](https://github.com/ibarakaiev/fireside/compare/v0.0.1...v0.0.2) (2024-07-21)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements - Changelog","doc":"- replace OTP application name in addition to module prefixes\n  (i.e. :my_app in addition to MyApp)","ref":"changelog.html#improvements"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}